# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/bigquery_logging_v1/proto/audit_data.proto

from cloudsdk.google.protobuf import descriptor as _descriptor
from cloudsdk.google.protobuf import message as _message
from cloudsdk.google.protobuf import reflection as _reflection
from cloudsdk.google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.iam.v1 import iam_policy_pb2 as google_dot_iam_dot_v1_dot_iam__policy__pb2
from google.iam.v1 import policy_pb2 as google_dot_iam_dot_v1_dot_policy__pb2
from cloudsdk.google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from cloudsdk.google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/cloud/bigquery_logging_v1/proto/audit_data.proto',
  package='google.cloud.bigquery.logging.v1',
  syntax='proto3',
  serialized_options=b'\n$com.google.cloud.bigquery.logging.v1B\016AuditDataProtoP\001ZGgoogle.golang.org/genproto/googleapis/cloud/bigquery/logging/v1;logging',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7google/cloud/bigquery_logging_v1/proto/audit_data.proto\x12 google.cloud.bigquery.logging.v1\x1a\x1egoogle/iam/v1/iam_policy.proto\x1a\x1agoogle/iam/v1/policy.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto\"\xac\x0e\n\tAuditData\x12T\n\x14table_insert_request\x18\x01 \x01(\x0b\x32\x34.google.cloud.bigquery.logging.v1.TableInsertRequestH\x00\x12T\n\x14table_update_request\x18\x10 \x01(\x0b\x32\x34.google.cloud.bigquery.logging.v1.TableUpdateRequestH\x00\x12T\n\x14\x64\x61taset_list_request\x18\x02 \x01(\x0b\x32\x34.google.cloud.bigquery.logging.v1.DatasetListRequestH\x00\x12X\n\x16\x64\x61taset_insert_request\x18\x03 \x01(\x0b\x32\x36.google.cloud.bigquery.logging.v1.DatasetInsertRequestH\x00\x12X\n\x16\x64\x61taset_update_request\x18\x04 \x01(\x0b\x32\x36.google.cloud.bigquery.logging.v1.DatasetUpdateRequestH\x00\x12P\n\x12job_insert_request\x18\x05 \x01(\x0b\x32\x32.google.cloud.bigquery.logging.v1.JobInsertRequestH\x00\x12N\n\x11job_query_request\x18\x06 \x01(\x0b\x32\x31.google.cloud.bigquery.logging.v1.JobQueryRequestH\x00\x12\x64\n\x1djob_get_query_results_request\x18\x07 \x01(\x0b\x32;.google.cloud.bigquery.logging.v1.JobGetQueryResultsRequestH\x00\x12Y\n\x17table_data_list_request\x18\x08 \x01(\x0b\x32\x36.google.cloud.bigquery.logging.v1.TableDataListRequestH\x00\x12\x44\n\x16set_iam_policy_request\x18\x14 \x01(\x0b\x32\".google.iam.v1.SetIamPolicyRequestH\x00\x12V\n\x15table_insert_response\x18\t \x01(\x0b\x32\x35.google.cloud.bigquery.logging.v1.TableInsertResponseH\x01\x12V\n\x15table_update_response\x18\n \x01(\x0b\x32\x35.google.cloud.bigquery.logging.v1.TableUpdateResponseH\x01\x12Z\n\x17\x64\x61taset_insert_response\x18\x0b \x01(\x0b\x32\x37.google.cloud.bigquery.logging.v1.DatasetInsertResponseH\x01\x12Z\n\x17\x64\x61taset_update_response\x18\x0c \x01(\x0b\x32\x37.google.cloud.bigquery.logging.v1.DatasetUpdateResponseH\x01\x12R\n\x13job_insert_response\x18\x12 \x01(\x0b\x32\x33.google.cloud.bigquery.logging.v1.JobInsertResponseH\x01\x12P\n\x12job_query_response\x18\r \x01(\x0b\x32\x32.google.cloud.bigquery.logging.v1.JobQueryResponseH\x01\x12\x66\n\x1ejob_get_query_results_response\x18\x0e \x01(\x0b\x32<.google.cloud.bigquery.logging.v1.JobGetQueryResultsResponseH\x01\x12Y\n\x17job_query_done_response\x18\x0f \x01(\x0b\x32\x36.google.cloud.bigquery.logging.v1.JobQueryDoneResponseH\x01\x12\x30\n\x0fpolicy_response\x18\x15 \x01(\x0b\x32\x15.google.iam.v1.PolicyH\x01\x12P\n\x13job_completed_event\x18\x11 \x01(\x0b\x32\x33.google.cloud.bigquery.logging.v1.JobCompletedEvent\x12T\n\x16table_data_read_events\x18\x13 \x03(\x0b\x32\x34.google.cloud.bigquery.logging.v1.TableDataReadEventB\t\n\x07requestB\n\n\x08response\"O\n\x12TableInsertRequest\x12\x39\n\x08resource\x18\x01 \x01(\x0b\x32\'.google.cloud.bigquery.logging.v1.Table\"O\n\x12TableUpdateRequest\x12\x39\n\x08resource\x18\x01 \x01(\x0b\x32\'.google.cloud.bigquery.logging.v1.Table\"P\n\x13TableInsertResponse\x12\x39\n\x08resource\x18\x01 \x01(\x0b\x32\'.google.cloud.bigquery.logging.v1.Table\"P\n\x13TableUpdateResponse\x12\x39\n\x08resource\x18\x01 \x01(\x0b\x32\'.google.cloud.bigquery.logging.v1.Table\"&\n\x12\x44\x61tasetListRequest\x12\x10\n\x08list_all\x18\x01 \x01(\x08\"S\n\x14\x44\x61tasetInsertRequest\x12;\n\x08resource\x18\x01 \x01(\x0b\x32).google.cloud.bigquery.logging.v1.Dataset\"T\n\x15\x44\x61tasetInsertResponse\x12;\n\x08resource\x18\x01 \x01(\x0b\x32).google.cloud.bigquery.logging.v1.Dataset\"S\n\x14\x44\x61tasetUpdateRequest\x12;\n\x08resource\x18\x01 \x01(\x0b\x32).google.cloud.bigquery.logging.v1.Dataset\"T\n\x15\x44\x61tasetUpdateResponse\x12;\n\x08resource\x18\x01 \x01(\x0b\x32).google.cloud.bigquery.logging.v1.Dataset\"K\n\x10JobInsertRequest\x12\x37\n\x08resource\x18\x01 \x01(\x0b\x32%.google.cloud.bigquery.logging.v1.Job\"L\n\x11JobInsertResponse\x12\x37\n\x08resource\x18\x01 \x01(\x0b\x32%.google.cloud.bigquery.logging.v1.Job\"\xa2\x01\n\x0fJobQueryRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12\x13\n\x0bmax_results\x18\x02 \x01(\r\x12\x46\n\x0f\x64\x65\x66\x61ult_dataset\x18\x03 \x01(\x0b\x32-.google.cloud.bigquery.logging.v1.DatasetName\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x0f\n\x07\x64ry_run\x18\x05 \x01(\x08\"]\n\x10JobQueryResponse\x12\x15\n\rtotal_results\x18\x01 \x01(\x04\x12\x32\n\x03job\x18\x02 \x01(\x0b\x32%.google.cloud.bigquery.logging.v1.Job\"C\n\x19JobGetQueryResultsRequest\x12\x13\n\x0bmax_results\x18\x01 \x01(\r\x12\x11\n\tstart_row\x18\x02 \x01(\x04\"g\n\x1aJobGetQueryResultsResponse\x12\x15\n\rtotal_results\x18\x01 \x01(\x04\x12\x32\n\x03job\x18\x02 \x01(\x0b\x32%.google.cloud.bigquery.logging.v1.Job\"J\n\x14JobQueryDoneResponse\x12\x32\n\x03job\x18\x01 \x01(\x0b\x32%.google.cloud.bigquery.logging.v1.Job\"[\n\x11JobCompletedEvent\x12\x12\n\nevent_name\x18\x01 \x01(\t\x12\x32\n\x03job\x18\x02 \x01(\x0b\x32%.google.cloud.bigquery.logging.v1.Job\"p\n\x12TableDataReadEvent\x12?\n\ntable_name\x18\x01 \x01(\x0b\x32+.google.cloud.bigquery.logging.v1.TableName\x12\x19\n\x11referenced_fields\x18\x02 \x03(\t\">\n\x14TableDataListRequest\x12\x11\n\tstart_row\x18\x01 \x01(\x04\x12\x13\n\x0bmax_results\x18\x02 \x01(\r\"\xe9\x03\n\x05Table\x12?\n\ntable_name\x18\x01 \x01(\x0b\x32+.google.cloud.bigquery.logging.v1.TableName\x12\x39\n\x04info\x18\x02 \x01(\x0b\x32+.google.cloud.bigquery.logging.v1.TableInfo\x12\x13\n\x0bschema_json\x18\x08 \x01(\t\x12\x43\n\x04view\x18\x04 \x01(\x0b\x32\x35.google.cloud.bigquery.logging.v1.TableViewDefinition\x12/\n\x0b\x65xpire_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x63reate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rtruncate_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bupdate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x44\n\nencryption\x18\n \x01(\x0b\x32\x30.google.cloud.bigquery.logging.v1.EncryptionInfo\"\xaf\x01\n\tTableInfo\x12\x15\n\rfriendly_name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12G\n\x06labels\x18\x03 \x03(\x0b\x32\x37.google.cloud.bigquery.logging.v1.TableInfo.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"$\n\x13TableViewDefinition\x12\r\n\x05query\x18\x01 \x01(\t\"\xeb\x02\n\x07\x44\x61taset\x12\x43\n\x0c\x64\x61taset_name\x18\x01 \x01(\x0b\x32-.google.cloud.bigquery.logging.v1.DatasetName\x12;\n\x04info\x18\x02 \x01(\x0b\x32-.google.cloud.bigquery.logging.v1.DatasetInfo\x12/\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bupdate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x03\x61\x63l\x18\x06 \x01(\x0b\x32-.google.cloud.bigquery.logging.v1.BigQueryAcl\x12@\n\x1d\x64\x65\x66\x61ult_table_expire_duration\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xb3\x01\n\x0b\x44\x61tasetInfo\x12\x15\n\rfriendly_name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12I\n\x06labels\x18\x03 \x03(\x0b\x32\x39.google.cloud.bigquery.logging.v1.DatasetInfo.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfb\x01\n\x0b\x42igQueryAcl\x12\x44\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x33.google.cloud.bigquery.logging.v1.BigQueryAcl.Entry\x1a\xa5\x01\n\x05\x45ntry\x12\x0c\n\x04role\x18\x01 \x01(\t\x12\x13\n\x0bgroup_email\x18\x02 \x01(\t\x12\x12\n\nuser_email\x18\x03 \x01(\t\x12\x0e\n\x06\x64omain\x18\x04 \x01(\t\x12\x15\n\rspecial_group\x18\x05 \x01(\t\x12>\n\tview_name\x18\x06 \x01(\x0b\x32+.google.cloud.bigquery.logging.v1.TableName\"\x9b\x02\n\x03Job\x12;\n\x08job_name\x18\x01 \x01(\x0b\x32).google.cloud.bigquery.logging.v1.JobName\x12M\n\x11job_configuration\x18\x02 \x01(\x0b\x32\x32.google.cloud.bigquery.logging.v1.JobConfiguration\x12?\n\njob_status\x18\x03 \x01(\x0b\x32+.google.cloud.bigquery.logging.v1.JobStatus\x12G\n\x0ejob_statistics\x18\x04 \x01(\x0b\x32/.google.cloud.bigquery.logging.v1.JobStatistics\"\xbb\x0c\n\x10JobConfiguration\x12I\n\x05query\x18\x05 \x01(\x0b\x32\x38.google.cloud.bigquery.logging.v1.JobConfiguration.QueryH\x00\x12G\n\x04load\x18\x06 \x01(\x0b\x32\x37.google.cloud.bigquery.logging.v1.JobConfiguration.LoadH\x00\x12M\n\x07\x65xtract\x18\x07 \x01(\x0b\x32:.google.cloud.bigquery.logging.v1.JobConfiguration.ExtractH\x00\x12R\n\ntable_copy\x18\x08 \x01(\x0b\x32<.google.cloud.bigquery.logging.v1.JobConfiguration.TableCopyH\x00\x12\x0f\n\x07\x64ry_run\x18\t \x01(\x08\x12N\n\x06labels\x18\x03 \x03(\x0b\x32>.google.cloud.bigquery.logging.v1.JobConfiguration.LabelsEntry\x1a\xb3\x03\n\x05Query\x12\r\n\x05query\x18\x01 \x01(\t\x12\x46\n\x11\x64\x65stination_table\x18\x02 \x01(\x0b\x32+.google.cloud.bigquery.logging.v1.TableName\x12\x1a\n\x12\x63reate_disposition\x18\x03 \x01(\t\x12\x19\n\x11write_disposition\x18\x04 \x01(\t\x12\x46\n\x0f\x64\x65\x66\x61ult_dataset\x18\x05 \x01(\x0b\x32-.google.cloud.bigquery.logging.v1.DatasetName\x12L\n\x11table_definitions\x18\x06 \x03(\x0b\x32\x31.google.cloud.bigquery.logging.v1.TableDefinition\x12\x16\n\x0equery_priority\x18\x07 \x01(\t\x12V\n\x1c\x64\x65stination_table_encryption\x18\x08 \x01(\x0b\x32\x30.google.cloud.bigquery.logging.v1.EncryptionInfo\x12\x16\n\x0estatement_type\x18\t \x01(\t\x1a\x87\x02\n\x04Load\x12\x13\n\x0bsource_uris\x18\x01 \x03(\t\x12\x13\n\x0bschema_json\x18\x06 \x01(\t\x12\x46\n\x11\x64\x65stination_table\x18\x03 \x01(\x0b\x32+.google.cloud.bigquery.logging.v1.TableName\x12\x1a\n\x12\x63reate_disposition\x18\x04 \x01(\t\x12\x19\n\x11write_disposition\x18\x05 \x01(\t\x12V\n\x1c\x64\x65stination_table_encryption\x18\x07 \x01(\x0b\x32\x30.google.cloud.bigquery.logging.v1.EncryptionInfo\x1a\x66\n\x07\x45xtract\x12\x18\n\x10\x64\x65stination_uris\x18\x01 \x03(\t\x12\x41\n\x0csource_table\x18\x02 \x01(\x0b\x32+.google.cloud.bigquery.logging.v1.TableName\x1a\xa6\x02\n\tTableCopy\x12\x42\n\rsource_tables\x18\x01 \x03(\x0b\x32+.google.cloud.bigquery.logging.v1.TableName\x12\x46\n\x11\x64\x65stination_table\x18\x02 \x01(\x0b\x32+.google.cloud.bigquery.logging.v1.TableName\x12\x1a\n\x12\x63reate_disposition\x18\x03 \x01(\t\x12\x19\n\x11write_disposition\x18\x04 \x01(\t\x12V\n\x1c\x64\x65stination_table_encryption\x18\x05 \x01(\x0b\x32\x30.google.cloud.bigquery.logging.v1.EncryptionInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0f\n\rconfiguration\"4\n\x0fTableDefinition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bsource_uris\x18\x02 \x03(\t\"l\n\tJobStatus\x12\r\n\x05state\x18\x01 \x01(\t\x12!\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x12.google.rpc.Status\x12-\n\x11\x61\x64\x64itional_errors\x18\x03 \x03(\x0b\x32\x12.google.rpc.Status\"\xb5\x05\n\rJobStatistics\x12/\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\x15total_processed_bytes\x18\x04 \x01(\x03\x12\x1a\n\x12total_billed_bytes\x18\x05 \x01(\x03\x12\x14\n\x0c\x62illing_tier\x18\x07 \x01(\x05\x12\x15\n\rtotal_slot_ms\x18\x08 \x01(\x03\x12\x63\n\x11reservation_usage\x18\x0e \x03(\x0b\x32H.google.cloud.bigquery.logging.v1.JobStatistics.ReservationResourceUsage\x12\x46\n\x11referenced_tables\x18\t \x03(\x0b\x32+.google.cloud.bigquery.logging.v1.TableName\x12\x1e\n\x16total_tables_processed\x18\n \x01(\x05\x12\x45\n\x10referenced_views\x18\x0b \x03(\x0b\x32+.google.cloud.bigquery.logging.v1.TableName\x12\x1d\n\x15total_views_processed\x18\x0c \x01(\x05\x12\x1e\n\x16query_output_row_count\x18\x0f \x01(\x03\x12\x1f\n\x17total_load_output_bytes\x18\r \x01(\x03\x1a\x39\n\x18ReservationResourceUsage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07slot_ms\x18\x02 \x01(\x03\"5\n\x0b\x44\x61tasetName\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x12\n\ndataset_id\x18\x02 \x01(\t\"E\n\tTableName\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x12\n\ndataset_id\x18\x02 \x01(\t\x12\x10\n\x08table_id\x18\x03 \x01(\t\"?\n\x07JobName\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\"&\n\x0e\x45ncryptionInfo\x12\x14\n\x0ckms_key_name\x18\x01 \x01(\tB\x81\x01\n$com.google.cloud.bigquery.logging.v1B\x0e\x41uditDataProtoP\x01ZGgoogle.golang.org/genproto/googleapis/cloud/bigquery/logging/v1;loggingb\x06proto3'
  ,
  dependencies=[google_dot_iam_dot_v1_dot_iam__policy__pb2.DESCRIPTOR,google_dot_iam_dot_v1_dot_policy__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,])




_AUDITDATA = _descriptor.Descriptor(
  name='AuditData',
  full_name='google.cloud.bigquery.logging.v1.AuditData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_insert_request', full_name='google.cloud.bigquery.logging.v1.AuditData.table_insert_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table_update_request', full_name='google.cloud.bigquery.logging.v1.AuditData.table_update_request', index=1,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset_list_request', full_name='google.cloud.bigquery.logging.v1.AuditData.dataset_list_request', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset_insert_request', full_name='google.cloud.bigquery.logging.v1.AuditData.dataset_insert_request', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset_update_request', full_name='google.cloud.bigquery.logging.v1.AuditData.dataset_update_request', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_insert_request', full_name='google.cloud.bigquery.logging.v1.AuditData.job_insert_request', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_query_request', full_name='google.cloud.bigquery.logging.v1.AuditData.job_query_request', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_get_query_results_request', full_name='google.cloud.bigquery.logging.v1.AuditData.job_get_query_results_request', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table_data_list_request', full_name='google.cloud.bigquery.logging.v1.AuditData.table_data_list_request', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_iam_policy_request', full_name='google.cloud.bigquery.logging.v1.AuditData.set_iam_policy_request', index=9,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table_insert_response', full_name='google.cloud.bigquery.logging.v1.AuditData.table_insert_response', index=10,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table_update_response', full_name='google.cloud.bigquery.logging.v1.AuditData.table_update_response', index=11,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset_insert_response', full_name='google.cloud.bigquery.logging.v1.AuditData.dataset_insert_response', index=12,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset_update_response', full_name='google.cloud.bigquery.logging.v1.AuditData.dataset_update_response', index=13,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_insert_response', full_name='google.cloud.bigquery.logging.v1.AuditData.job_insert_response', index=14,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_query_response', full_name='google.cloud.bigquery.logging.v1.AuditData.job_query_response', index=15,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_get_query_results_response', full_name='google.cloud.bigquery.logging.v1.AuditData.job_get_query_results_response', index=16,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_query_done_response', full_name='google.cloud.bigquery.logging.v1.AuditData.job_query_done_response', index=17,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='policy_response', full_name='google.cloud.bigquery.logging.v1.AuditData.policy_response', index=18,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_completed_event', full_name='google.cloud.bigquery.logging.v1.AuditData.job_completed_event', index=19,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table_data_read_events', full_name='google.cloud.bigquery.logging.v1.AuditData.table_data_read_events', index=20,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request', full_name='google.cloud.bigquery.logging.v1.AuditData.request',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='response', full_name='google.cloud.bigquery.logging.v1.AuditData.response',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=244,
  serialized_end=2080,
)


_TABLEINSERTREQUEST = _descriptor.Descriptor(
  name='TableInsertRequest',
  full_name='google.cloud.bigquery.logging.v1.TableInsertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource', full_name='google.cloud.bigquery.logging.v1.TableInsertRequest.resource', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2082,
  serialized_end=2161,
)


_TABLEUPDATEREQUEST = _descriptor.Descriptor(
  name='TableUpdateRequest',
  full_name='google.cloud.bigquery.logging.v1.TableUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource', full_name='google.cloud.bigquery.logging.v1.TableUpdateRequest.resource', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2163,
  serialized_end=2242,
)


_TABLEINSERTRESPONSE = _descriptor.Descriptor(
  name='TableInsertResponse',
  full_name='google.cloud.bigquery.logging.v1.TableInsertResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource', full_name='google.cloud.bigquery.logging.v1.TableInsertResponse.resource', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2244,
  serialized_end=2324,
)


_TABLEUPDATERESPONSE = _descriptor.Descriptor(
  name='TableUpdateResponse',
  full_name='google.cloud.bigquery.logging.v1.TableUpdateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource', full_name='google.cloud.bigquery.logging.v1.TableUpdateResponse.resource', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2326,
  serialized_end=2406,
)


_DATASETLISTREQUEST = _descriptor.Descriptor(
  name='DatasetListRequest',
  full_name='google.cloud.bigquery.logging.v1.DatasetListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='list_all', full_name='google.cloud.bigquery.logging.v1.DatasetListRequest.list_all', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2408,
  serialized_end=2446,
)


_DATASETINSERTREQUEST = _descriptor.Descriptor(
  name='DatasetInsertRequest',
  full_name='google.cloud.bigquery.logging.v1.DatasetInsertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource', full_name='google.cloud.bigquery.logging.v1.DatasetInsertRequest.resource', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2448,
  serialized_end=2531,
)


_DATASETINSERTRESPONSE = _descriptor.Descriptor(
  name='DatasetInsertResponse',
  full_name='google.cloud.bigquery.logging.v1.DatasetInsertResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource', full_name='google.cloud.bigquery.logging.v1.DatasetInsertResponse.resource', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2533,
  serialized_end=2617,
)


_DATASETUPDATEREQUEST = _descriptor.Descriptor(
  name='DatasetUpdateRequest',
  full_name='google.cloud.bigquery.logging.v1.DatasetUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource', full_name='google.cloud.bigquery.logging.v1.DatasetUpdateRequest.resource', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2619,
  serialized_end=2702,
)


_DATASETUPDATERESPONSE = _descriptor.Descriptor(
  name='DatasetUpdateResponse',
  full_name='google.cloud.bigquery.logging.v1.DatasetUpdateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource', full_name='google.cloud.bigquery.logging.v1.DatasetUpdateResponse.resource', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2704,
  serialized_end=2788,
)


_JOBINSERTREQUEST = _descriptor.Descriptor(
  name='JobInsertRequest',
  full_name='google.cloud.bigquery.logging.v1.JobInsertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource', full_name='google.cloud.bigquery.logging.v1.JobInsertRequest.resource', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2790,
  serialized_end=2865,
)


_JOBINSERTRESPONSE = _descriptor.Descriptor(
  name='JobInsertResponse',
  full_name='google.cloud.bigquery.logging.v1.JobInsertResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource', full_name='google.cloud.bigquery.logging.v1.JobInsertResponse.resource', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2867,
  serialized_end=2943,
)


_JOBQUERYREQUEST = _descriptor.Descriptor(
  name='JobQueryRequest',
  full_name='google.cloud.bigquery.logging.v1.JobQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='google.cloud.bigquery.logging.v1.JobQueryRequest.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_results', full_name='google.cloud.bigquery.logging.v1.JobQueryRequest.max_results', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_dataset', full_name='google.cloud.bigquery.logging.v1.JobQueryRequest.default_dataset', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project_id', full_name='google.cloud.bigquery.logging.v1.JobQueryRequest.project_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dry_run', full_name='google.cloud.bigquery.logging.v1.JobQueryRequest.dry_run', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2946,
  serialized_end=3108,
)


_JOBQUERYRESPONSE = _descriptor.Descriptor(
  name='JobQueryResponse',
  full_name='google.cloud.bigquery.logging.v1.JobQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_results', full_name='google.cloud.bigquery.logging.v1.JobQueryResponse.total_results', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job', full_name='google.cloud.bigquery.logging.v1.JobQueryResponse.job', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3110,
  serialized_end=3203,
)


_JOBGETQUERYRESULTSREQUEST = _descriptor.Descriptor(
  name='JobGetQueryResultsRequest',
  full_name='google.cloud.bigquery.logging.v1.JobGetQueryResultsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_results', full_name='google.cloud.bigquery.logging.v1.JobGetQueryResultsRequest.max_results', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_row', full_name='google.cloud.bigquery.logging.v1.JobGetQueryResultsRequest.start_row', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3205,
  serialized_end=3272,
)


_JOBGETQUERYRESULTSRESPONSE = _descriptor.Descriptor(
  name='JobGetQueryResultsResponse',
  full_name='google.cloud.bigquery.logging.v1.JobGetQueryResultsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_results', full_name='google.cloud.bigquery.logging.v1.JobGetQueryResultsResponse.total_results', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job', full_name='google.cloud.bigquery.logging.v1.JobGetQueryResultsResponse.job', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3274,
  serialized_end=3377,
)


_JOBQUERYDONERESPONSE = _descriptor.Descriptor(
  name='JobQueryDoneResponse',
  full_name='google.cloud.bigquery.logging.v1.JobQueryDoneResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job', full_name='google.cloud.bigquery.logging.v1.JobQueryDoneResponse.job', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3379,
  serialized_end=3453,
)


_JOBCOMPLETEDEVENT = _descriptor.Descriptor(
  name='JobCompletedEvent',
  full_name='google.cloud.bigquery.logging.v1.JobCompletedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_name', full_name='google.cloud.bigquery.logging.v1.JobCompletedEvent.event_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job', full_name='google.cloud.bigquery.logging.v1.JobCompletedEvent.job', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3455,
  serialized_end=3546,
)


_TABLEDATAREADEVENT = _descriptor.Descriptor(
  name='TableDataReadEvent',
  full_name='google.cloud.bigquery.logging.v1.TableDataReadEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_name', full_name='google.cloud.bigquery.logging.v1.TableDataReadEvent.table_name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='referenced_fields', full_name='google.cloud.bigquery.logging.v1.TableDataReadEvent.referenced_fields', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3548,
  serialized_end=3660,
)


_TABLEDATALISTREQUEST = _descriptor.Descriptor(
  name='TableDataListRequest',
  full_name='google.cloud.bigquery.logging.v1.TableDataListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_row', full_name='google.cloud.bigquery.logging.v1.TableDataListRequest.start_row', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_results', full_name='google.cloud.bigquery.logging.v1.TableDataListRequest.max_results', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3662,
  serialized_end=3724,
)


_TABLE = _descriptor.Descriptor(
  name='Table',
  full_name='google.cloud.bigquery.logging.v1.Table',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_name', full_name='google.cloud.bigquery.logging.v1.Table.table_name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='info', full_name='google.cloud.bigquery.logging.v1.Table.info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema_json', full_name='google.cloud.bigquery.logging.v1.Table.schema_json', index=2,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view', full_name='google.cloud.bigquery.logging.v1.Table.view', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expire_time', full_name='google.cloud.bigquery.logging.v1.Table.expire_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='google.cloud.bigquery.logging.v1.Table.create_time', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='truncate_time', full_name='google.cloud.bigquery.logging.v1.Table.truncate_time', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_time', full_name='google.cloud.bigquery.logging.v1.Table.update_time', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encryption', full_name='google.cloud.bigquery.logging.v1.Table.encryption', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3727,
  serialized_end=4216,
)


_TABLEINFO_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='google.cloud.bigquery.logging.v1.TableInfo.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.cloud.bigquery.logging.v1.TableInfo.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.cloud.bigquery.logging.v1.TableInfo.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4349,
  serialized_end=4394,
)

_TABLEINFO = _descriptor.Descriptor(
  name='TableInfo',
  full_name='google.cloud.bigquery.logging.v1.TableInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='friendly_name', full_name='google.cloud.bigquery.logging.v1.TableInfo.friendly_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='google.cloud.bigquery.logging.v1.TableInfo.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='google.cloud.bigquery.logging.v1.TableInfo.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TABLEINFO_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4219,
  serialized_end=4394,
)


_TABLEVIEWDEFINITION = _descriptor.Descriptor(
  name='TableViewDefinition',
  full_name='google.cloud.bigquery.logging.v1.TableViewDefinition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='google.cloud.bigquery.logging.v1.TableViewDefinition.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4396,
  serialized_end=4432,
)


_DATASET = _descriptor.Descriptor(
  name='Dataset',
  full_name='google.cloud.bigquery.logging.v1.Dataset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset_name', full_name='google.cloud.bigquery.logging.v1.Dataset.dataset_name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='info', full_name='google.cloud.bigquery.logging.v1.Dataset.info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='google.cloud.bigquery.logging.v1.Dataset.create_time', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_time', full_name='google.cloud.bigquery.logging.v1.Dataset.update_time', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acl', full_name='google.cloud.bigquery.logging.v1.Dataset.acl', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_table_expire_duration', full_name='google.cloud.bigquery.logging.v1.Dataset.default_table_expire_duration', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4435,
  serialized_end=4798,
)


_DATASETINFO_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='google.cloud.bigquery.logging.v1.DatasetInfo.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.cloud.bigquery.logging.v1.DatasetInfo.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.cloud.bigquery.logging.v1.DatasetInfo.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4349,
  serialized_end=4394,
)

_DATASETINFO = _descriptor.Descriptor(
  name='DatasetInfo',
  full_name='google.cloud.bigquery.logging.v1.DatasetInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='friendly_name', full_name='google.cloud.bigquery.logging.v1.DatasetInfo.friendly_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='google.cloud.bigquery.logging.v1.DatasetInfo.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='google.cloud.bigquery.logging.v1.DatasetInfo.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DATASETINFO_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4801,
  serialized_end=4980,
)


_BIGQUERYACL_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='google.cloud.bigquery.logging.v1.BigQueryAcl.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='role', full_name='google.cloud.bigquery.logging.v1.BigQueryAcl.Entry.role', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group_email', full_name='google.cloud.bigquery.logging.v1.BigQueryAcl.Entry.group_email', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_email', full_name='google.cloud.bigquery.logging.v1.BigQueryAcl.Entry.user_email', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='domain', full_name='google.cloud.bigquery.logging.v1.BigQueryAcl.Entry.domain', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='special_group', full_name='google.cloud.bigquery.logging.v1.BigQueryAcl.Entry.special_group', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view_name', full_name='google.cloud.bigquery.logging.v1.BigQueryAcl.Entry.view_name', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5069,
  serialized_end=5234,
)

_BIGQUERYACL = _descriptor.Descriptor(
  name='BigQueryAcl',
  full_name='google.cloud.bigquery.logging.v1.BigQueryAcl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='google.cloud.bigquery.logging.v1.BigQueryAcl.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BIGQUERYACL_ENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4983,
  serialized_end=5234,
)


_JOB = _descriptor.Descriptor(
  name='Job',
  full_name='google.cloud.bigquery.logging.v1.Job',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_name', full_name='google.cloud.bigquery.logging.v1.Job.job_name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_configuration', full_name='google.cloud.bigquery.logging.v1.Job.job_configuration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_status', full_name='google.cloud.bigquery.logging.v1.Job.job_status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_statistics', full_name='google.cloud.bigquery.logging.v1.Job.job_statistics', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5237,
  serialized_end=5520,
)


_JOBCONFIGURATION_QUERY = _descriptor.Descriptor(
  name='Query',
  full_name='google.cloud.bigquery.logging.v1.JobConfiguration.Query',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.Query.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_table', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.Query.destination_table', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_disposition', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.Query.create_disposition', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='write_disposition', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.Query.write_disposition', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_dataset', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.Query.default_dataset', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table_definitions', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.Query.table_definitions', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_priority', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.Query.query_priority', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_table_encryption', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.Query.destination_table_encryption', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statement_type', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.Query.statement_type', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5952,
  serialized_end=6387,
)

_JOBCONFIGURATION_LOAD = _descriptor.Descriptor(
  name='Load',
  full_name='google.cloud.bigquery.logging.v1.JobConfiguration.Load',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_uris', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.Load.source_uris', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema_json', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.Load.schema_json', index=1,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_table', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.Load.destination_table', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_disposition', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.Load.create_disposition', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='write_disposition', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.Load.write_disposition', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_table_encryption', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.Load.destination_table_encryption', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6390,
  serialized_end=6653,
)

_JOBCONFIGURATION_EXTRACT = _descriptor.Descriptor(
  name='Extract',
  full_name='google.cloud.bigquery.logging.v1.JobConfiguration.Extract',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='destination_uris', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.Extract.destination_uris', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_table', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.Extract.source_table', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6655,
  serialized_end=6757,
)

_JOBCONFIGURATION_TABLECOPY = _descriptor.Descriptor(
  name='TableCopy',
  full_name='google.cloud.bigquery.logging.v1.JobConfiguration.TableCopy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_tables', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.TableCopy.source_tables', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_table', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.TableCopy.destination_table', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_disposition', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.TableCopy.create_disposition', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='write_disposition', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.TableCopy.write_disposition', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_table_encryption', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.TableCopy.destination_table_encryption', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6760,
  serialized_end=7054,
)

_JOBCONFIGURATION_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='google.cloud.bigquery.logging.v1.JobConfiguration.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4349,
  serialized_end=4394,
)

_JOBCONFIGURATION = _descriptor.Descriptor(
  name='JobConfiguration',
  full_name='google.cloud.bigquery.logging.v1.JobConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.query', index=0,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.load', index=1,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extract', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.extract', index=2,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table_copy', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.table_copy', index=3,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dry_run', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.dry_run', index=4,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.labels', index=5,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_JOBCONFIGURATION_QUERY, _JOBCONFIGURATION_LOAD, _JOBCONFIGURATION_EXTRACT, _JOBCONFIGURATION_TABLECOPY, _JOBCONFIGURATION_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='configuration', full_name='google.cloud.bigquery.logging.v1.JobConfiguration.configuration',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5523,
  serialized_end=7118,
)


_TABLEDEFINITION = _descriptor.Descriptor(
  name='TableDefinition',
  full_name='google.cloud.bigquery.logging.v1.TableDefinition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.cloud.bigquery.logging.v1.TableDefinition.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_uris', full_name='google.cloud.bigquery.logging.v1.TableDefinition.source_uris', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7120,
  serialized_end=7172,
)


_JOBSTATUS = _descriptor.Descriptor(
  name='JobStatus',
  full_name='google.cloud.bigquery.logging.v1.JobStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='google.cloud.bigquery.logging.v1.JobStatus.state', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='google.cloud.bigquery.logging.v1.JobStatus.error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additional_errors', full_name='google.cloud.bigquery.logging.v1.JobStatus.additional_errors', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7174,
  serialized_end=7282,
)


_JOBSTATISTICS_RESERVATIONRESOURCEUSAGE = _descriptor.Descriptor(
  name='ReservationResourceUsage',
  full_name='google.cloud.bigquery.logging.v1.JobStatistics.ReservationResourceUsage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.cloud.bigquery.logging.v1.JobStatistics.ReservationResourceUsage.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slot_ms', full_name='google.cloud.bigquery.logging.v1.JobStatistics.ReservationResourceUsage.slot_ms', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7921,
  serialized_end=7978,
)

_JOBSTATISTICS = _descriptor.Descriptor(
  name='JobStatistics',
  full_name='google.cloud.bigquery.logging.v1.JobStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='create_time', full_name='google.cloud.bigquery.logging.v1.JobStatistics.create_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='google.cloud.bigquery.logging.v1.JobStatistics.start_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='google.cloud.bigquery.logging.v1.JobStatistics.end_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_processed_bytes', full_name='google.cloud.bigquery.logging.v1.JobStatistics.total_processed_bytes', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_billed_bytes', full_name='google.cloud.bigquery.logging.v1.JobStatistics.total_billed_bytes', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billing_tier', full_name='google.cloud.bigquery.logging.v1.JobStatistics.billing_tier', index=5,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_slot_ms', full_name='google.cloud.bigquery.logging.v1.JobStatistics.total_slot_ms', index=6,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reservation_usage', full_name='google.cloud.bigquery.logging.v1.JobStatistics.reservation_usage', index=7,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='referenced_tables', full_name='google.cloud.bigquery.logging.v1.JobStatistics.referenced_tables', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_tables_processed', full_name='google.cloud.bigquery.logging.v1.JobStatistics.total_tables_processed', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='referenced_views', full_name='google.cloud.bigquery.logging.v1.JobStatistics.referenced_views', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_views_processed', full_name='google.cloud.bigquery.logging.v1.JobStatistics.total_views_processed', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_output_row_count', full_name='google.cloud.bigquery.logging.v1.JobStatistics.query_output_row_count', index=12,
      number=15, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_load_output_bytes', full_name='google.cloud.bigquery.logging.v1.JobStatistics.total_load_output_bytes', index=13,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_JOBSTATISTICS_RESERVATIONRESOURCEUSAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7285,
  serialized_end=7978,
)


_DATASETNAME = _descriptor.Descriptor(
  name='DatasetName',
  full_name='google.cloud.bigquery.logging.v1.DatasetName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='google.cloud.bigquery.logging.v1.DatasetName.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='google.cloud.bigquery.logging.v1.DatasetName.dataset_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7980,
  serialized_end=8033,
)


_TABLENAME = _descriptor.Descriptor(
  name='TableName',
  full_name='google.cloud.bigquery.logging.v1.TableName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='google.cloud.bigquery.logging.v1.TableName.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset_id', full_name='google.cloud.bigquery.logging.v1.TableName.dataset_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table_id', full_name='google.cloud.bigquery.logging.v1.TableName.table_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8035,
  serialized_end=8104,
)


_JOBNAME = _descriptor.Descriptor(
  name='JobName',
  full_name='google.cloud.bigquery.logging.v1.JobName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='google.cloud.bigquery.logging.v1.JobName.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='google.cloud.bigquery.logging.v1.JobName.job_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='google.cloud.bigquery.logging.v1.JobName.location', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8106,
  serialized_end=8169,
)


_ENCRYPTIONINFO = _descriptor.Descriptor(
  name='EncryptionInfo',
  full_name='google.cloud.bigquery.logging.v1.EncryptionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kms_key_name', full_name='google.cloud.bigquery.logging.v1.EncryptionInfo.kms_key_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8171,
  serialized_end=8209,
)

_AUDITDATA.fields_by_name['table_insert_request'].message_type = _TABLEINSERTREQUEST
_AUDITDATA.fields_by_name['table_update_request'].message_type = _TABLEUPDATEREQUEST
_AUDITDATA.fields_by_name['dataset_list_request'].message_type = _DATASETLISTREQUEST
_AUDITDATA.fields_by_name['dataset_insert_request'].message_type = _DATASETINSERTREQUEST
_AUDITDATA.fields_by_name['dataset_update_request'].message_type = _DATASETUPDATEREQUEST
_AUDITDATA.fields_by_name['job_insert_request'].message_type = _JOBINSERTREQUEST
_AUDITDATA.fields_by_name['job_query_request'].message_type = _JOBQUERYREQUEST
_AUDITDATA.fields_by_name['job_get_query_results_request'].message_type = _JOBGETQUERYRESULTSREQUEST
_AUDITDATA.fields_by_name['table_data_list_request'].message_type = _TABLEDATALISTREQUEST
_AUDITDATA.fields_by_name['set_iam_policy_request'].message_type = google_dot_iam_dot_v1_dot_iam__policy__pb2._SETIAMPOLICYREQUEST
_AUDITDATA.fields_by_name['table_insert_response'].message_type = _TABLEINSERTRESPONSE
_AUDITDATA.fields_by_name['table_update_response'].message_type = _TABLEUPDATERESPONSE
_AUDITDATA.fields_by_name['dataset_insert_response'].message_type = _DATASETINSERTRESPONSE
_AUDITDATA.fields_by_name['dataset_update_response'].message_type = _DATASETUPDATERESPONSE
_AUDITDATA.fields_by_name['job_insert_response'].message_type = _JOBINSERTRESPONSE
_AUDITDATA.fields_by_name['job_query_response'].message_type = _JOBQUERYRESPONSE
_AUDITDATA.fields_by_name['job_get_query_results_response'].message_type = _JOBGETQUERYRESULTSRESPONSE
_AUDITDATA.fields_by_name['job_query_done_response'].message_type = _JOBQUERYDONERESPONSE
_AUDITDATA.fields_by_name['policy_response'].message_type = google_dot_iam_dot_v1_dot_policy__pb2._POLICY
_AUDITDATA.fields_by_name['job_completed_event'].message_type = _JOBCOMPLETEDEVENT
_AUDITDATA.fields_by_name['table_data_read_events'].message_type = _TABLEDATAREADEVENT
_AUDITDATA.oneofs_by_name['request'].fields.append(
  _AUDITDATA.fields_by_name['table_insert_request'])
_AUDITDATA.fields_by_name['table_insert_request'].containing_oneof = _AUDITDATA.oneofs_by_name['request']
_AUDITDATA.oneofs_by_name['request'].fields.append(
  _AUDITDATA.fields_by_name['table_update_request'])
_AUDITDATA.fields_by_name['table_update_request'].containing_oneof = _AUDITDATA.oneofs_by_name['request']
_AUDITDATA.oneofs_by_name['request'].fields.append(
  _AUDITDATA.fields_by_name['dataset_list_request'])
_AUDITDATA.fields_by_name['dataset_list_request'].containing_oneof = _AUDITDATA.oneofs_by_name['request']
_AUDITDATA.oneofs_by_name['request'].fields.append(
  _AUDITDATA.fields_by_name['dataset_insert_request'])
_AUDITDATA.fields_by_name['dataset_insert_request'].containing_oneof = _AUDITDATA.oneofs_by_name['request']
_AUDITDATA.oneofs_by_name['request'].fields.append(
  _AUDITDATA.fields_by_name['dataset_update_request'])
_AUDITDATA.fields_by_name['dataset_update_request'].containing_oneof = _AUDITDATA.oneofs_by_name['request']
_AUDITDATA.oneofs_by_name['request'].fields.append(
  _AUDITDATA.fields_by_name['job_insert_request'])
_AUDITDATA.fields_by_name['job_insert_request'].containing_oneof = _AUDITDATA.oneofs_by_name['request']
_AUDITDATA.oneofs_by_name['request'].fields.append(
  _AUDITDATA.fields_by_name['job_query_request'])
_AUDITDATA.fields_by_name['job_query_request'].containing_oneof = _AUDITDATA.oneofs_by_name['request']
_AUDITDATA.oneofs_by_name['request'].fields.append(
  _AUDITDATA.fields_by_name['job_get_query_results_request'])
_AUDITDATA.fields_by_name['job_get_query_results_request'].containing_oneof = _AUDITDATA.oneofs_by_name['request']
_AUDITDATA.oneofs_by_name['request'].fields.append(
  _AUDITDATA.fields_by_name['table_data_list_request'])
_AUDITDATA.fields_by_name['table_data_list_request'].containing_oneof = _AUDITDATA.oneofs_by_name['request']
_AUDITDATA.oneofs_by_name['request'].fields.append(
  _AUDITDATA.fields_by_name['set_iam_policy_request'])
_AUDITDATA.fields_by_name['set_iam_policy_request'].containing_oneof = _AUDITDATA.oneofs_by_name['request']
_AUDITDATA.oneofs_by_name['response'].fields.append(
  _AUDITDATA.fields_by_name['table_insert_response'])
_AUDITDATA.fields_by_name['table_insert_response'].containing_oneof = _AUDITDATA.oneofs_by_name['response']
_AUDITDATA.oneofs_by_name['response'].fields.append(
  _AUDITDATA.fields_by_name['table_update_response'])
_AUDITDATA.fields_by_name['table_update_response'].containing_oneof = _AUDITDATA.oneofs_by_name['response']
_AUDITDATA.oneofs_by_name['response'].fields.append(
  _AUDITDATA.fields_by_name['dataset_insert_response'])
_AUDITDATA.fields_by_name['dataset_insert_response'].containing_oneof = _AUDITDATA.oneofs_by_name['response']
_AUDITDATA.oneofs_by_name['response'].fields.append(
  _AUDITDATA.fields_by_name['dataset_update_response'])
_AUDITDATA.fields_by_name['dataset_update_response'].containing_oneof = _AUDITDATA.oneofs_by_name['response']
_AUDITDATA.oneofs_by_name['response'].fields.append(
  _AUDITDATA.fields_by_name['job_insert_response'])
_AUDITDATA.fields_by_name['job_insert_response'].containing_oneof = _AUDITDATA.oneofs_by_name['response']
_AUDITDATA.oneofs_by_name['response'].fields.append(
  _AUDITDATA.fields_by_name['job_query_response'])
_AUDITDATA.fields_by_name['job_query_response'].containing_oneof = _AUDITDATA.oneofs_by_name['response']
_AUDITDATA.oneofs_by_name['response'].fields.append(
  _AUDITDATA.fields_by_name['job_get_query_results_response'])
_AUDITDATA.fields_by_name['job_get_query_results_response'].containing_oneof = _AUDITDATA.oneofs_by_name['response']
_AUDITDATA.oneofs_by_name['response'].fields.append(
  _AUDITDATA.fields_by_name['job_query_done_response'])
_AUDITDATA.fields_by_name['job_query_done_response'].containing_oneof = _AUDITDATA.oneofs_by_name['response']
_AUDITDATA.oneofs_by_name['response'].fields.append(
  _AUDITDATA.fields_by_name['policy_response'])
_AUDITDATA.fields_by_name['policy_response'].containing_oneof = _AUDITDATA.oneofs_by_name['response']
_TABLEINSERTREQUEST.fields_by_name['resource'].message_type = _TABLE
_TABLEUPDATEREQUEST.fields_by_name['resource'].message_type = _TABLE
_TABLEINSERTRESPONSE.fields_by_name['resource'].message_type = _TABLE
_TABLEUPDATERESPONSE.fields_by_name['resource'].message_type = _TABLE
_DATASETINSERTREQUEST.fields_by_name['resource'].message_type = _DATASET
_DATASETINSERTRESPONSE.fields_by_name['resource'].message_type = _DATASET
_DATASETUPDATEREQUEST.fields_by_name['resource'].message_type = _DATASET
_DATASETUPDATERESPONSE.fields_by_name['resource'].message_type = _DATASET
_JOBINSERTREQUEST.fields_by_name['resource'].message_type = _JOB
_JOBINSERTRESPONSE.fields_by_name['resource'].message_type = _JOB
_JOBQUERYREQUEST.fields_by_name['default_dataset'].message_type = _DATASETNAME
_JOBQUERYRESPONSE.fields_by_name['job'].message_type = _JOB
_JOBGETQUERYRESULTSRESPONSE.fields_by_name['job'].message_type = _JOB
_JOBQUERYDONERESPONSE.fields_by_name['job'].message_type = _JOB
_JOBCOMPLETEDEVENT.fields_by_name['job'].message_type = _JOB
_TABLEDATAREADEVENT.fields_by_name['table_name'].message_type = _TABLENAME
_TABLE.fields_by_name['table_name'].message_type = _TABLENAME
_TABLE.fields_by_name['info'].message_type = _TABLEINFO
_TABLE.fields_by_name['view'].message_type = _TABLEVIEWDEFINITION
_TABLE.fields_by_name['expire_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TABLE.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TABLE.fields_by_name['truncate_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TABLE.fields_by_name['update_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TABLE.fields_by_name['encryption'].message_type = _ENCRYPTIONINFO
_TABLEINFO_LABELSENTRY.containing_type = _TABLEINFO
_TABLEINFO.fields_by_name['labels'].message_type = _TABLEINFO_LABELSENTRY
_DATASET.fields_by_name['dataset_name'].message_type = _DATASETNAME
_DATASET.fields_by_name['info'].message_type = _DATASETINFO
_DATASET.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DATASET.fields_by_name['update_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DATASET.fields_by_name['acl'].message_type = _BIGQUERYACL
_DATASET.fields_by_name['default_table_expire_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_DATASETINFO_LABELSENTRY.containing_type = _DATASETINFO
_DATASETINFO.fields_by_name['labels'].message_type = _DATASETINFO_LABELSENTRY
_BIGQUERYACL_ENTRY.fields_by_name['view_name'].message_type = _TABLENAME
_BIGQUERYACL_ENTRY.containing_type = _BIGQUERYACL
_BIGQUERYACL.fields_by_name['entries'].message_type = _BIGQUERYACL_ENTRY
_JOB.fields_by_name['job_name'].message_type = _JOBNAME
_JOB.fields_by_name['job_configuration'].message_type = _JOBCONFIGURATION
_JOB.fields_by_name['job_status'].message_type = _JOBSTATUS
_JOB.fields_by_name['job_statistics'].message_type = _JOBSTATISTICS
_JOBCONFIGURATION_QUERY.fields_by_name['destination_table'].message_type = _TABLENAME
_JOBCONFIGURATION_QUERY.fields_by_name['default_dataset'].message_type = _DATASETNAME
_JOBCONFIGURATION_QUERY.fields_by_name['table_definitions'].message_type = _TABLEDEFINITION
_JOBCONFIGURATION_QUERY.fields_by_name['destination_table_encryption'].message_type = _ENCRYPTIONINFO
_JOBCONFIGURATION_QUERY.containing_type = _JOBCONFIGURATION
_JOBCONFIGURATION_LOAD.fields_by_name['destination_table'].message_type = _TABLENAME
_JOBCONFIGURATION_LOAD.fields_by_name['destination_table_encryption'].message_type = _ENCRYPTIONINFO
_JOBCONFIGURATION_LOAD.containing_type = _JOBCONFIGURATION
_JOBCONFIGURATION_EXTRACT.fields_by_name['source_table'].message_type = _TABLENAME
_JOBCONFIGURATION_EXTRACT.containing_type = _JOBCONFIGURATION
_JOBCONFIGURATION_TABLECOPY.fields_by_name['source_tables'].message_type = _TABLENAME
_JOBCONFIGURATION_TABLECOPY.fields_by_name['destination_table'].message_type = _TABLENAME
_JOBCONFIGURATION_TABLECOPY.fields_by_name['destination_table_encryption'].message_type = _ENCRYPTIONINFO
_JOBCONFIGURATION_TABLECOPY.containing_type = _JOBCONFIGURATION
_JOBCONFIGURATION_LABELSENTRY.containing_type = _JOBCONFIGURATION
_JOBCONFIGURATION.fields_by_name['query'].message_type = _JOBCONFIGURATION_QUERY
_JOBCONFIGURATION.fields_by_name['load'].message_type = _JOBCONFIGURATION_LOAD
_JOBCONFIGURATION.fields_by_name['extract'].message_type = _JOBCONFIGURATION_EXTRACT
_JOBCONFIGURATION.fields_by_name['table_copy'].message_type = _JOBCONFIGURATION_TABLECOPY
_JOBCONFIGURATION.fields_by_name['labels'].message_type = _JOBCONFIGURATION_LABELSENTRY
_JOBCONFIGURATION.oneofs_by_name['configuration'].fields.append(
  _JOBCONFIGURATION.fields_by_name['query'])
_JOBCONFIGURATION.fields_by_name['query'].containing_oneof = _JOBCONFIGURATION.oneofs_by_name['configuration']
_JOBCONFIGURATION.oneofs_by_name['configuration'].fields.append(
  _JOBCONFIGURATION.fields_by_name['load'])
_JOBCONFIGURATION.fields_by_name['load'].containing_oneof = _JOBCONFIGURATION.oneofs_by_name['configuration']
_JOBCONFIGURATION.oneofs_by_name['configuration'].fields.append(
  _JOBCONFIGURATION.fields_by_name['extract'])
_JOBCONFIGURATION.fields_by_name['extract'].containing_oneof = _JOBCONFIGURATION.oneofs_by_name['configuration']
_JOBCONFIGURATION.oneofs_by_name['configuration'].fields.append(
  _JOBCONFIGURATION.fields_by_name['table_copy'])
_JOBCONFIGURATION.fields_by_name['table_copy'].containing_oneof = _JOBCONFIGURATION.oneofs_by_name['configuration']
_JOBSTATUS.fields_by_name['error'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_JOBSTATUS.fields_by_name['additional_errors'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_JOBSTATISTICS_RESERVATIONRESOURCEUSAGE.containing_type = _JOBSTATISTICS
_JOBSTATISTICS.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOBSTATISTICS.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOBSTATISTICS.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_JOBSTATISTICS.fields_by_name['reservation_usage'].message_type = _JOBSTATISTICS_RESERVATIONRESOURCEUSAGE
_JOBSTATISTICS.fields_by_name['referenced_tables'].message_type = _TABLENAME
_JOBSTATISTICS.fields_by_name['referenced_views'].message_type = _TABLENAME
DESCRIPTOR.message_types_by_name['AuditData'] = _AUDITDATA
DESCRIPTOR.message_types_by_name['TableInsertRequest'] = _TABLEINSERTREQUEST
DESCRIPTOR.message_types_by_name['TableUpdateRequest'] = _TABLEUPDATEREQUEST
DESCRIPTOR.message_types_by_name['TableInsertResponse'] = _TABLEINSERTRESPONSE
DESCRIPTOR.message_types_by_name['TableUpdateResponse'] = _TABLEUPDATERESPONSE
DESCRIPTOR.message_types_by_name['DatasetListRequest'] = _DATASETLISTREQUEST
DESCRIPTOR.message_types_by_name['DatasetInsertRequest'] = _DATASETINSERTREQUEST
DESCRIPTOR.message_types_by_name['DatasetInsertResponse'] = _DATASETINSERTRESPONSE
DESCRIPTOR.message_types_by_name['DatasetUpdateRequest'] = _DATASETUPDATEREQUEST
DESCRIPTOR.message_types_by_name['DatasetUpdateResponse'] = _DATASETUPDATERESPONSE
DESCRIPTOR.message_types_by_name['JobInsertRequest'] = _JOBINSERTREQUEST
DESCRIPTOR.message_types_by_name['JobInsertResponse'] = _JOBINSERTRESPONSE
DESCRIPTOR.message_types_by_name['JobQueryRequest'] = _JOBQUERYREQUEST
DESCRIPTOR.message_types_by_name['JobQueryResponse'] = _JOBQUERYRESPONSE
DESCRIPTOR.message_types_by_name['JobGetQueryResultsRequest'] = _JOBGETQUERYRESULTSREQUEST
DESCRIPTOR.message_types_by_name['JobGetQueryResultsResponse'] = _JOBGETQUERYRESULTSRESPONSE
DESCRIPTOR.message_types_by_name['JobQueryDoneResponse'] = _JOBQUERYDONERESPONSE
DESCRIPTOR.message_types_by_name['JobCompletedEvent'] = _JOBCOMPLETEDEVENT
DESCRIPTOR.message_types_by_name['TableDataReadEvent'] = _TABLEDATAREADEVENT
DESCRIPTOR.message_types_by_name['TableDataListRequest'] = _TABLEDATALISTREQUEST
DESCRIPTOR.message_types_by_name['Table'] = _TABLE
DESCRIPTOR.message_types_by_name['TableInfo'] = _TABLEINFO
DESCRIPTOR.message_types_by_name['TableViewDefinition'] = _TABLEVIEWDEFINITION
DESCRIPTOR.message_types_by_name['Dataset'] = _DATASET
DESCRIPTOR.message_types_by_name['DatasetInfo'] = _DATASETINFO
DESCRIPTOR.message_types_by_name['BigQueryAcl'] = _BIGQUERYACL
DESCRIPTOR.message_types_by_name['Job'] = _JOB
DESCRIPTOR.message_types_by_name['JobConfiguration'] = _JOBCONFIGURATION
DESCRIPTOR.message_types_by_name['TableDefinition'] = _TABLEDEFINITION
DESCRIPTOR.message_types_by_name['JobStatus'] = _JOBSTATUS
DESCRIPTOR.message_types_by_name['JobStatistics'] = _JOBSTATISTICS
DESCRIPTOR.message_types_by_name['DatasetName'] = _DATASETNAME
DESCRIPTOR.message_types_by_name['TableName'] = _TABLENAME
DESCRIPTOR.message_types_by_name['JobName'] = _JOBNAME
DESCRIPTOR.message_types_by_name['EncryptionInfo'] = _ENCRYPTIONINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AuditData = _reflection.GeneratedProtocolMessageType('AuditData', (_message.Message,), {
  'DESCRIPTOR' : _AUDITDATA,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """BigQuery request and response messages for audit log. Note:
  ``Table.schema`` has been deprecated in favor of ``Table.schemaJson``.
  ``Table.schema`` may continue to be present in your logs during this
  transition.
  
  Attributes:
      request:
          Request data for each BigQuery method.
      table_insert_request:
          Table insert request.
      table_update_request:
          Table update request.
      dataset_list_request:
          Dataset list request.
      dataset_insert_request:
          Dataset insert request.
      dataset_update_request:
          Dataset update request.
      job_insert_request:
          Job insert request.
      job_query_request:
          Job query request.
      job_get_query_results_request:
          Job get query results request.
      table_data_list_request:
          Table data-list request.
      set_iam_policy_request:
          Iam policy request.
      response:
          Response data for each BigQuery method.
      table_insert_response:
          Table insert response.
      table_update_response:
          Table update response.
      dataset_insert_response:
          Dataset insert response.
      dataset_update_response:
          Dataset update response.
      job_insert_response:
          Job insert response.
      job_query_response:
          Job query response.
      job_get_query_results_response:
          Job get query results response.
      job_query_done_response:
          Deprecated: Job query-done response. Use this information for
          usage analysis.
      policy_response:
          Iam Policy.
      job_completed_event:
          A job completion event.
      table_data_read_events:
          Information about the table access events.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.AuditData)
  })
_sym_db.RegisterMessage(AuditData)

TableInsertRequest = _reflection.GeneratedProtocolMessageType('TableInsertRequest', (_message.Message,), {
  'DESCRIPTOR' : _TABLEINSERTREQUEST,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Table insert request.
  
  Attributes:
      resource:
          The new table.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.TableInsertRequest)
  })
_sym_db.RegisterMessage(TableInsertRequest)

TableUpdateRequest = _reflection.GeneratedProtocolMessageType('TableUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _TABLEUPDATEREQUEST,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Table update request.
  
  Attributes:
      resource:
          The table to be updated.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.TableUpdateRequest)
  })
_sym_db.RegisterMessage(TableUpdateRequest)

TableInsertResponse = _reflection.GeneratedProtocolMessageType('TableInsertResponse', (_message.Message,), {
  'DESCRIPTOR' : _TABLEINSERTRESPONSE,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Table insert response.
  
  Attributes:
      resource:
          Final state of the inserted table.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.TableInsertResponse)
  })
_sym_db.RegisterMessage(TableInsertResponse)

TableUpdateResponse = _reflection.GeneratedProtocolMessageType('TableUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _TABLEUPDATERESPONSE,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Table update response.
  
  Attributes:
      resource:
          Final state of the updated table.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.TableUpdateResponse)
  })
_sym_db.RegisterMessage(TableUpdateResponse)

DatasetListRequest = _reflection.GeneratedProtocolMessageType('DatasetListRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASETLISTREQUEST,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Dataset list request.
  
  Attributes:
      list_all:
          Whether to list all datasets, including hidden ones.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.DatasetListRequest)
  })
_sym_db.RegisterMessage(DatasetListRequest)

DatasetInsertRequest = _reflection.GeneratedProtocolMessageType('DatasetInsertRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASETINSERTREQUEST,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Dataset insert request.
  
  Attributes:
      resource:
          The dataset to be inserted.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.DatasetInsertRequest)
  })
_sym_db.RegisterMessage(DatasetInsertRequest)

DatasetInsertResponse = _reflection.GeneratedProtocolMessageType('DatasetInsertResponse', (_message.Message,), {
  'DESCRIPTOR' : _DATASETINSERTRESPONSE,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Dataset insert response.
  
  Attributes:
      resource:
          Final state of the inserted dataset.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.DatasetInsertResponse)
  })
_sym_db.RegisterMessage(DatasetInsertResponse)

DatasetUpdateRequest = _reflection.GeneratedProtocolMessageType('DatasetUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASETUPDATEREQUEST,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Dataset update request.
  
  Attributes:
      resource:
          The dataset to be updated.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.DatasetUpdateRequest)
  })
_sym_db.RegisterMessage(DatasetUpdateRequest)

DatasetUpdateResponse = _reflection.GeneratedProtocolMessageType('DatasetUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _DATASETUPDATERESPONSE,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Dataset update response.
  
  Attributes:
      resource:
          Final state of the updated dataset.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.DatasetUpdateResponse)
  })
_sym_db.RegisterMessage(DatasetUpdateResponse)

JobInsertRequest = _reflection.GeneratedProtocolMessageType('JobInsertRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOBINSERTREQUEST,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Job insert request.
  
  Attributes:
      resource:
          Job insert request.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.JobInsertRequest)
  })
_sym_db.RegisterMessage(JobInsertRequest)

JobInsertResponse = _reflection.GeneratedProtocolMessageType('JobInsertResponse', (_message.Message,), {
  'DESCRIPTOR' : _JOBINSERTRESPONSE,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Job insert response.
  
  Attributes:
      resource:
          Job insert response.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.JobInsertResponse)
  })
_sym_db.RegisterMessage(JobInsertResponse)

JobQueryRequest = _reflection.GeneratedProtocolMessageType('JobQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOBQUERYREQUEST,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Job query request.
  
  Attributes:
      query:
          The query.
      max_results:
          The maximum number of results.
      default_dataset:
          The default dataset for tables that do not have a dataset
          specified.
      project_id:
          Project that the query should be charged to.
      dry_run:
          If true, don’t actually run the job. Just check that it would
          run.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.JobQueryRequest)
  })
_sym_db.RegisterMessage(JobQueryRequest)

JobQueryResponse = _reflection.GeneratedProtocolMessageType('JobQueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _JOBQUERYRESPONSE,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Job query response.
  
  Attributes:
      total_results:
          The total number of rows in the full query result set.
      job:
          Information about the queried job.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.JobQueryResponse)
  })
_sym_db.RegisterMessage(JobQueryResponse)

JobGetQueryResultsRequest = _reflection.GeneratedProtocolMessageType('JobGetQueryResultsRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOBGETQUERYRESULTSREQUEST,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Job getQueryResults request.
  
  Attributes:
      max_results:
          Maximum number of results to return.
      start_row:
          Zero-based row number at which to start.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.JobGetQueryResultsRequest)
  })
_sym_db.RegisterMessage(JobGetQueryResultsRequest)

JobGetQueryResultsResponse = _reflection.GeneratedProtocolMessageType('JobGetQueryResultsResponse', (_message.Message,), {
  'DESCRIPTOR' : _JOBGETQUERYRESULTSRESPONSE,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Job getQueryResults response.
  
  Attributes:
      total_results:
          Total number of results in query results.
      job:
          The job that was created to run the query. It completed if
          ``job.status.state`` is ``DONE``. It failed if
          ``job.status.errorResult`` is also present.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.JobGetQueryResultsResponse)
  })
_sym_db.RegisterMessage(JobGetQueryResultsResponse)

JobQueryDoneResponse = _reflection.GeneratedProtocolMessageType('JobQueryDoneResponse', (_message.Message,), {
  'DESCRIPTOR' : _JOBQUERYDONERESPONSE,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Job getQueryDone response.
  
  Attributes:
      job:
          The job and status information. The job completed if
          ``job.status.state`` is ``DONE``.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.JobQueryDoneResponse)
  })
_sym_db.RegisterMessage(JobQueryDoneResponse)

JobCompletedEvent = _reflection.GeneratedProtocolMessageType('JobCompletedEvent', (_message.Message,), {
  'DESCRIPTOR' : _JOBCOMPLETEDEVENT,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Query job completed event.
  
  Attributes:
      event_name:
          Name of the event.
      job:
          Job information.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.JobCompletedEvent)
  })
_sym_db.RegisterMessage(JobCompletedEvent)

TableDataReadEvent = _reflection.GeneratedProtocolMessageType('TableDataReadEvent', (_message.Message,), {
  'DESCRIPTOR' : _TABLEDATAREADEVENT,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Table data read event. Only present for tables, not views, and is only
  included in the log record for the project that owns the table.
  
  Attributes:
      table_name:
          Name of the accessed table.
      referenced_fields:
          A list of referenced fields. This information is not included
          by default. To enable this in the logs, please contact
          BigQuery support or open a bug in the BigQuery issue tracker.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.TableDataReadEvent)
  })
_sym_db.RegisterMessage(TableDataReadEvent)

TableDataListRequest = _reflection.GeneratedProtocolMessageType('TableDataListRequest', (_message.Message,), {
  'DESCRIPTOR' : _TABLEDATALISTREQUEST,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Table data-list request.
  
  Attributes:
      start_row:
          Starting row offset.
      max_results:
          Maximum number of results to return.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.TableDataListRequest)
  })
_sym_db.RegisterMessage(TableDataListRequest)

Table = _reflection.GeneratedProtocolMessageType('Table', (_message.Message,), {
  'DESCRIPTOR' : _TABLE,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Describes a BigQuery table. See the `Table
  </bigquery/docs/reference/v2/tables>`__ API resource for more details
  on individual fields. Note: ``Table.schema`` has been deprecated in
  favor of ``Table.schemaJson``. ``Table.schema`` may continue to be
  present in your logs during this transition.
  
  Attributes:
      table_name:
          The name of the table.
      info:
          User-provided metadata for the table.
      schema_json:
          A JSON representation of the table’s schema.
      view:
          If present, this is a virtual table defined by a SQL query.
      expire_time:
          The expiration date for the table, after which the table is
          deleted and the storage reclaimed. If not present, the table
          persists indefinitely.
      create_time:
          The time the table was created.
      truncate_time:
          The time the table was last truncated by an operation with a
          ``writeDisposition`` of ``WRITE_TRUNCATE``.
      update_time:
          The time the table was last modified.
      encryption:
          The table encryption information. Set when non-default
          encryption is used.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.Table)
  })
_sym_db.RegisterMessage(Table)

TableInfo = _reflection.GeneratedProtocolMessageType('TableInfo', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _TABLEINFO_LABELSENTRY,
    '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
    # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.TableInfo.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _TABLEINFO,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """User-provided metadata for a table.
  
  Attributes:
      friendly_name:
          A short name for the table, such as\ ``"Analytics Data - Jan
          2011"``.
      description:
          A long description, perhaps several paragraphs, describing the
          table contents in detail.
      labels:
          Labels provided for the table.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.TableInfo)
  })
_sym_db.RegisterMessage(TableInfo)
_sym_db.RegisterMessage(TableInfo.LabelsEntry)

TableViewDefinition = _reflection.GeneratedProtocolMessageType('TableViewDefinition', (_message.Message,), {
  'DESCRIPTOR' : _TABLEVIEWDEFINITION,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Describes a virtual table defined by a SQL query.
  
  Attributes:
      query:
          SQL query defining the view.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.TableViewDefinition)
  })
_sym_db.RegisterMessage(TableViewDefinition)

Dataset = _reflection.GeneratedProtocolMessageType('Dataset', (_message.Message,), {
  'DESCRIPTOR' : _DATASET,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """BigQuery dataset information. See the `Dataset
  </bigquery/docs/reference/v2/datasets>`__ API resource for more
  details on individual fields.
  
  Attributes:
      dataset_name:
          The name of the dataset.
      info:
          User-provided metadata for the dataset.
      create_time:
          The time the dataset was created.
      update_time:
          The time the dataset was last modified.
      acl:
          The access control list for the dataset.
      default_table_expire_duration:
          If this field is present, each table that does not specify an
          expiration time is assigned an expiration time by adding this
          duration to the table’s ``createTime``. If this field is
          empty, there is no default table expiration time.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.Dataset)
  })
_sym_db.RegisterMessage(Dataset)

DatasetInfo = _reflection.GeneratedProtocolMessageType('DatasetInfo', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETINFO_LABELSENTRY,
    '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
    # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.DatasetInfo.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _DATASETINFO,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """User-provided metadata for a dataset.
  
  Attributes:
      friendly_name:
          A short name for the dataset, such as\ ``"Analytics Data
          2011"``.
      description:
          A long description, perhaps several paragraphs, describing the
          dataset contents in detail.
      labels:
          Labels provided for the dataset.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.DatasetInfo)
  })
_sym_db.RegisterMessage(DatasetInfo)
_sym_db.RegisterMessage(DatasetInfo.LabelsEntry)

BigQueryAcl = _reflection.GeneratedProtocolMessageType('BigQueryAcl', (_message.Message,), {

  'Entry' : _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), {
    'DESCRIPTOR' : _BIGQUERYACL_ENTRY,
    '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
    ,
    '__doc__': """Access control entry.
    
    Attributes:
        role:
            The granted role, which can be ``READER``, ``WRITER``, or
            ``OWNER``.
        group_email:
            Grants access to a group identified by an email address.
        user_email:
            Grants access to a user identified by an email address.
        domain:
            Grants access to all members of a domain.
        special_group:
            Grants access to special groups. Valid groups are
            ``PROJECT_OWNERS``, ``PROJECT_READERS``, ``PROJECT_WRITERS``
            and ``ALL_AUTHENTICATED_USERS``.
        view_name:
            Grants access to a BigQuery View.
    """,
    # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.BigQueryAcl.Entry)
    })
  ,
  'DESCRIPTOR' : _BIGQUERYACL,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """An access control list.
  
  Attributes:
      entries:
          Access control entry list.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.BigQueryAcl)
  })
_sym_db.RegisterMessage(BigQueryAcl)
_sym_db.RegisterMessage(BigQueryAcl.Entry)

Job = _reflection.GeneratedProtocolMessageType('Job', (_message.Message,), {
  'DESCRIPTOR' : _JOB,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Describes a job.
  
  Attributes:
      job_name:
          Job name.
      job_configuration:
          Job configuration.
      job_status:
          Job status.
      job_statistics:
          Job statistics.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.Job)
  })
_sym_db.RegisterMessage(Job)

JobConfiguration = _reflection.GeneratedProtocolMessageType('JobConfiguration', (_message.Message,), {

  'Query' : _reflection.GeneratedProtocolMessageType('Query', (_message.Message,), {
    'DESCRIPTOR' : _JOBCONFIGURATION_QUERY,
    '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
    ,
    '__doc__': """Describes a query job, which executes a SQL-like query.
    
    Attributes:
        query:
            The SQL query to run.
        destination_table:
            The table where results are written.
        create_disposition:
            Describes when a job is allowed to create a table:
            ``CREATE_IF_NEEDED``, ``CREATE_NEVER``.
        write_disposition:
            Describes how writes affect existing tables:
            ``WRITE_TRUNCATE``, ``WRITE_APPEND``, ``WRITE_EMPTY``.
        default_dataset:
            If a table name is specified without a dataset in a query,
            this dataset will be added to table name.
        table_definitions:
            Describes data sources outside BigQuery, if needed.
        query_priority:
            Describes the priority given to the query:
            ``QUERY_INTERACTIVE`` or ``QUERY_BATCH``.
        destination_table_encryption:
            Result table encryption information. Set when non-default
            encryption is used.
        statement_type:
            Type of the statement (e.g. SELECT, INSERT, CREATE_TABLE,
            CREATE_MODEL..)
    """,
    # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.JobConfiguration.Query)
    })
  ,

  'Load' : _reflection.GeneratedProtocolMessageType('Load', (_message.Message,), {
    'DESCRIPTOR' : _JOBCONFIGURATION_LOAD,
    '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
    ,
    '__doc__': """Describes a load job, which loads data from an external source via the
    import pipeline.
    
    Attributes:
        source_uris:
            URIs for the data to be imported. Only Google Cloud Storage
            URIs are supported.
        schema_json:
            The table schema in JSON format representation of a
            TableSchema.
        destination_table:
            The table where the imported data is written.
        create_disposition:
            Describes when a job is allowed to create a table:
            ``CREATE_IF_NEEDED``, ``CREATE_NEVER``.
        write_disposition:
            Describes how writes affect existing tables:
            ``WRITE_TRUNCATE``, ``WRITE_APPEND``, ``WRITE_EMPTY``.
        destination_table_encryption:
            Result table encryption information. Set when non-default
            encryption is used.
    """,
    # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.JobConfiguration.Load)
    })
  ,

  'Extract' : _reflection.GeneratedProtocolMessageType('Extract', (_message.Message,), {
    'DESCRIPTOR' : _JOBCONFIGURATION_EXTRACT,
    '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
    ,
    '__doc__': """Describes an extract job, which exports data to an external source via
    the export pipeline.
    
    Attributes:
        destination_uris:
            Google Cloud Storage URIs where extracted data should be
            written.
        source_table:
            The source table.
    """,
    # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.JobConfiguration.Extract)
    })
  ,

  'TableCopy' : _reflection.GeneratedProtocolMessageType('TableCopy', (_message.Message,), {
    'DESCRIPTOR' : _JOBCONFIGURATION_TABLECOPY,
    '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
    ,
    '__doc__': """Describes a copy job, which copies an existing table to another table.
    
    Attributes:
        source_tables:
            Source tables.
        destination_table:
            Destination table.
        create_disposition:
            Describes when a job is allowed to create a table:
            ``CREATE_IF_NEEDED``, ``CREATE_NEVER``.
        write_disposition:
            Describes how writes affect existing tables:
            ``WRITE_TRUNCATE``, ``WRITE_APPEND``, ``WRITE_EMPTY``.
        destination_table_encryption:
            Result table encryption information. Set when non-default
            encryption is used.
    """,
    # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.JobConfiguration.TableCopy)
    })
  ,

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _JOBCONFIGURATION_LABELSENTRY,
    '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
    # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.JobConfiguration.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _JOBCONFIGURATION,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Job configuration information. See the `Jobs
  </bigquery/docs/reference/v2/jobs>`__ API resource for more details on
  individual fields.
  
  Attributes:
      configuration:
          Job configuration information.
      query:
          Query job information.
      load:
          Load job information.
      extract:
          Extract job information.
      table_copy:
          TableCopy job information.
      dry_run:
          If true, don’t actually run the job. Just check that it would
          run.
      labels:
          Labels provided for the job.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.JobConfiguration)
  })
_sym_db.RegisterMessage(JobConfiguration)
_sym_db.RegisterMessage(JobConfiguration.Query)
_sym_db.RegisterMessage(JobConfiguration.Load)
_sym_db.RegisterMessage(JobConfiguration.Extract)
_sym_db.RegisterMessage(JobConfiguration.TableCopy)
_sym_db.RegisterMessage(JobConfiguration.LabelsEntry)

TableDefinition = _reflection.GeneratedProtocolMessageType('TableDefinition', (_message.Message,), {
  'DESCRIPTOR' : _TABLEDEFINITION,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Describes an external data source used in a query.
  
  Attributes:
      name:
          Name of the table, used in queries.
      source_uris:
          Google Cloud Storage URIs for the data to be imported.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.TableDefinition)
  })
_sym_db.RegisterMessage(TableDefinition)

JobStatus = _reflection.GeneratedProtocolMessageType('JobStatus', (_message.Message,), {
  'DESCRIPTOR' : _JOBSTATUS,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Running state of a job.
  
  Attributes:
      state:
          State of a job: ``PENDING``, ``RUNNING``, or ``DONE``.
      error:
          If the job did not complete successfully, this field describes
          why.
      additional_errors:
          Errors encountered during the running of the job. Do not
          necessarily mean that the job has completed or was
          unsuccessful.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.JobStatus)
  })
_sym_db.RegisterMessage(JobStatus)

JobStatistics = _reflection.GeneratedProtocolMessageType('JobStatistics', (_message.Message,), {

  'ReservationResourceUsage' : _reflection.GeneratedProtocolMessageType('ReservationResourceUsage', (_message.Message,), {
    'DESCRIPTOR' : _JOBSTATISTICS_RESERVATIONRESOURCEUSAGE,
    '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
    ,
    '__doc__': """Job resource usage breakdown by reservation.
    
    Attributes:
        name:
            Reservation name or “unreserved” for on-demand resources
            usage.
        slot_ms:
            Total slot milliseconds used by the reservation for a
            particular job.
    """,
    # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.JobStatistics.ReservationResourceUsage)
    })
  ,
  'DESCRIPTOR' : _JOBSTATISTICS,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Job statistics that may change after a job starts.
  
  Attributes:
      create_time:
          Time when the job was created.
      start_time:
          Time when the job started.
      end_time:
          Time when the job ended.
      total_processed_bytes:
          Total bytes processed for a job.
      total_billed_bytes:
          Processed bytes, adjusted by the job’s CPU usage.
      billing_tier:
          The tier assigned by CPU-based billing.
      total_slot_ms:
          The total number of slot-ms consumed by the query job.
      reservation_usage:
          Reservation usage.
      referenced_tables:
          The first N tables accessed by the query job. Older queries
          that reference a large number of tables may not have all of
          their tables in this list. You can use the
          total_tables_processed count to know how many total tables
          were read in the query. For new queries, there is currently no
          limit.
      total_tables_processed:
          Total number of unique tables referenced in the query.
      referenced_views:
          The first N views accessed by the query job. Older queries
          that reference a large number of views may not have all of
          their views in this list. You can use the
          total_tables_processed count to know how many total tables
          were read in the query. For new queries, there is currently no
          limit.
      total_views_processed:
          Total number of unique views referenced in the query.
      query_output_row_count:
          Number of output rows produced by the query job.
      total_load_output_bytes:
          Total bytes loaded for an import job.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.JobStatistics)
  })
_sym_db.RegisterMessage(JobStatistics)
_sym_db.RegisterMessage(JobStatistics.ReservationResourceUsage)

DatasetName = _reflection.GeneratedProtocolMessageType('DatasetName', (_message.Message,), {
  'DESCRIPTOR' : _DATASETNAME,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """The fully-qualified name for a dataset.
  
  Attributes:
      project_id:
          The project ID.
      dataset_id:
          The dataset ID within the project.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.DatasetName)
  })
_sym_db.RegisterMessage(DatasetName)

TableName = _reflection.GeneratedProtocolMessageType('TableName', (_message.Message,), {
  'DESCRIPTOR' : _TABLENAME,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """The fully-qualified name for a table.
  
  Attributes:
      project_id:
          The project ID.
      dataset_id:
          The dataset ID within the project.
      table_id:
          The table ID of the table within the dataset.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.TableName)
  })
_sym_db.RegisterMessage(TableName)

JobName = _reflection.GeneratedProtocolMessageType('JobName', (_message.Message,), {
  'DESCRIPTOR' : _JOBNAME,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """The fully-qualified name for a job.
  
  Attributes:
      project_id:
          The project ID.
      job_id:
          The job ID within the project.
      location:
          The job location.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.JobName)
  })
_sym_db.RegisterMessage(JobName)

EncryptionInfo = _reflection.GeneratedProtocolMessageType('EncryptionInfo', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTIONINFO,
  '__module__' : 'google.cloud.bigquery_logging_v1.proto.audit_data_pb2'
  ,
  '__doc__': """Describes encryption properties for a table or a job
  
  Attributes:
      kms_key_name:
          unique identifier for cloud kms key
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.bigquery.logging.v1.EncryptionInfo)
  })
_sym_db.RegisterMessage(EncryptionInfo)


DESCRIPTOR._options = None
_TABLEINFO_LABELSENTRY._options = None
_DATASETINFO_LABELSENTRY._options = None
_JOBCONFIGURATION_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)
